"use strict";
var http = require("http");
var uuid = require("uuid");
var core_1 = require("@msg/core");
var http_request_1 = require("./messages/http.request");
var http_response_1 = require("./messages/http.response");
var app = new core_1.App("http");
var server;
var responses = {};
app.on(core_1.AppStart, function (message, context) {
    server = http.createServer(function (request, response) {
        var req = new http_request_1.HttpRequest();
        var responseId = uuid.v1();
        req.url = request.url;
        req.method = request.method;
        req.headers = request.headers;
        req.httpVersion = request.httpVersion;
        req.httpVersionMajor = request.httpVersionMajor;
        req.httpVersionMinor = request.httpVersionMinor;
        responses[responseId] = response;
        context.source.context.responseId = responseId;
        var chunks = [];
        request
            .on('data', function (chunk) {
            chunks.push(chunk);
        })
            .on('end', function () {
            req.body = Buffer.concat(chunks).toString();
            context.emit(req);
        });
    });
    var port = app.config['port'] || process.env.PORT || 3000;
    var hostname = app.config['hostname'] || 'localhost';
    server.listen(port, hostname, function (err) {
        if (err) {
            return console.error(err);
        }
        context.emit(new core_1.AppStarted());
    });
});
app.on(core_1.AppStop, function (message, context) {
    server.close(function () {
        context.emit(new core_1.AppStopped());
    });
});
app.on(http_response_1.HttpResponse, function (message, context) {
    var responseId = context.source.context.responseId;
    if (!responseId) {
        console.log("no response id!");
        return;
    }
    var response = responses[responseId];
    if (!response) {
        console.log(responseId + " does not exist!");
        return;
    }
    response.writeHead(message.statusCode, message.headers);
    response.end(message.body);
    delete response[responseId];
});
module.exports = app;
//# sourceMappingURL=app.js.map